<!DOCTYPE html>
<html xmlns='http://www.w3.org/1999/xhtml'>
  <head>
    <title>Code coverage for <%= SimpleCov.project_name %></title>
    <meta http-equiv="content-type" content="text/html; charset=utf-8" />
    <script src='<%= assets_path('application.js') %>' type='text/javascript'></script>
    <link href='<%= assets_path('application.css') %>' media='screen, projection, print' rel='stylesheet' type='text/css' />
    <link rel="icon" type="image/png" href="<%= assets_path("favicon_#{coverage_css_class(result.source_files.covered_percent)}.png") %>" />
  </head>

  <body<%= ' data-branch-coverage=true' if branchable_result? %>>
    <div id="loading">
      <img src="<%= assets_path('loading.gif') %>" alt="loading"/>
    </div>
    <div id="wrapper" class="hide">
      <div class="timestamp">Generated <%= timeago(Time.now) %></div>
      <ul class="group_tabs"></ul>

      <div id="content">
        <%= formatted_file_list("All Files", result.source_files) %>

        <% result.groups.each do |name, files| %>
          <%= formatted_file_list(name, files) %>
        <% end %>
      </div>

      <div id="footer">
        Generated by <a href="https://github.com/simplecov-ruby/simplecov">simplecov</a> v<%= SimpleCov::VERSION %>
        and simplecov-html v<%= SimpleCov::Formatter::HTMLFormatter::VERSION %><br/>
        using <%= result.command_name %>
      </div>

      <div class="source_files">
      <% result.source_files.each do |source_file| %>
        <%= formatted_source_file(source_file) %>
      <% end %>
      </div>
    </div>
  </body>
</html>
